@@ -1638,8 +1638,14 @@ if (!is.null(save_results)) {
   write.csv(mat_res_XX, save_results, row.names = TRUE, col.names = TRUE)
 }
 
-Effect_mat <- mat_res_XX[1:l_XX, 1:(ncol(mat_res_XX) -1)]
-ATE_mat <- mat_res_XX[l_XX + 1, 1:(ncol(mat_res_XX) -1)]
+Effect_mat <- matrix(mat_res_XX[1:l_XX, 1:(ncol(mat_res_XX) -1)], ncol = ncol(mat_res_XX)-1, nrow = l_XX)
+rownames(Effect_mat) <- rownames[1:l_XX]
+colnames(Effect_mat) <- c("Estimate", "SE", "LB CI", "UB CI", "N", "Switchers")
+
+ATE_mat <- matrix(mat_res_XX[l_XX + 1, 1:(ncol(mat_res_XX) -1)], ncol = ncol(mat_res_XX)-1, nrow = 1)
+rownames(ATE_mat) <- rownames[l_XX+1]
+colnames(ATE_mat) <- c("Estimate", "SE", "LB CI", "UB CI", "N", "Switchers")
+
 out_names <- c("N_Effects", "N_Placebos", "Effects", "ATE")
 did_multiplegt_dyn <- list(
   l_XX,
@@ -1652,7 +1658,11 @@ if (isTRUE(effects_equal)) {
   out_names <- c(out_names, "p_equality_effects")  
 }
 if (placebo != 0) {
-  Placebo_mat <- mat_res_XX[(l_XX+2):nrow(mat_res_XX), 1:(ncol(mat_res_XX) -1)]
+  Placebo_mat <- matrix(mat_res_XX[(l_XX+2):nrow(mat_res_XX), 1:(ncol(mat_res_XX) -1)], ncol = ncol(mat_res_XX) -1, nrow = l_placebo_XX)
+  rownames(Placebo_mat) <- rownames[(l_XX+2):nrow(mat_res_XX)]
+  colnames(Placebo_mat) <- c("Estimate", "SE", "LB CI", "UB CI", "N", "Switchers")
+
+
   did_multiplegt_dyn <- append(did_multiplegt_dyn, list(Placebo_mat))
   out_names <- c(out_names, "Placebos")
   if (placebo > 1) {
